--=========================================================================================
-- BUSHEL PLUS SCRIPT
--
-- @For:		bcbuhler
-- @Date:		2021-04-11
-- @Purpose:	Script allows yield improvements using Bushel Plus combine attachment.
--=========================================================================================

--[[NOTE:	The 'scale' to use in the vehicle's xml file is the amount of increase/decrease
			one wishes to see.  If one wishes to see a 10% increase in yield as a result of
			attaching this mod, then the scale factor should be set to 0.10.]]


BushelPlus = {};

function BushelPlus.prerequisitesPresent(specializations)
	return true;
end;

function BushelPlus.registerFunctions(vehicleType)
end

function BushelPlus.registerOverwrittenFunctions(vehicleType)
end;

function BushelPlus.registerEventListeners(vehicleType)
	SpecializationUtil.registerEventListener(vehicleType, "onLoad", BushelPlus);
	SpecializationUtil.registerEventListener(vehicleType, "onPostAttach", BushelPlus);
	SpecializationUtil.registerEventListener(vehicleType, "onPreDetach", BushelPlus);
end;

function BushelPlus:onLoad(savegame)
	local scale = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.bushelPlus#scale"), 0);
	self.spec_BushelPlus = {};
	local spec = self.spec_BushelPlus
	spec.bushelYieldScale = scale;
end;

function BushelPlus:onPostAttach(attacherVehicle, inputJointIndex, jointDescIndex)

	local attacherVehicle = self:getAttacherVehicle();
	if attacherVehicle ~= nil and attacherVehicle.verifyCombine ~= nil then
	
		-- If we're attached to a combine apply Bushel Plus yield adjustment.
		local spec = self.spec_BushelPlus;
		local comSpec = attacherVehicle.spec_combine;
		comSpec.threshingScale = comSpec.threshingScale * (1 + spec.bushelYieldScale);
	end;
end;

function BushelPlus:onPreDetach(attacherVehicle, implement)

	local attacherVehicle = self:getAttacherVehicle();
	if attacherVehicle ~= nil and attacherVehicle.verifyCombine ~= nil then
	
		-- If we're detaching from a combine, re-set the threshing scale.
		local spec = self.spec_BushelPlus;
		local comSpec = attacherVehicle.spec_combine;
		comSpec.threshingScale = comSpec.threshingScale / (1 + spec.bushelYieldScale);
	end;
end;